@@ -11,24 +11,29 @@ import pluggdapps.interfaces
 
 import pagd.interfaces
 
-try    :
+try:
     from   mako.template import Template
     from   mako.runtime import Context
-    class Mako( Plugin ):
-        """Plugin to translate mako templates to html files."""
-        implements( pagd.interfaces.ITemplate )
+except : pass
 
-        def __init__( self ):
-            self.kwargs = {
-                'module_directory' : \
-                        self['siteconfig'].get('mako.module_directory', None),
-            }
+class Mako( Plugin ):
+    """Plugin to translate mako templates to html files."""
+    implements( pagd.interfaces.ITemplate )
 
-        def render( self, page ):
+    extensions = ['mako']
+
+    def __init__( self ):
+        self.kwargs = {
+            'module_directory' : \
+                    self['siteconfig'].get('mako.module_directory', None),
+        }
+
+    def render( self, page ):
+        try :
             mytemplate = Template( page.templatefile, **self.kwargs )
             buf = io.StringIO()
             mytemplate.render_context( Context(buf, **page.context) )
             return buf.getvalue()
-except :
-    pass
+        except NameError :
+            return ''
 
